@@ -20,8 +20,10 @@
 # You should have received a copy of the GNU General Public License
 # along with PGP Gajim Plugin. If not, see <http://www.gnu.org/licenses/>.
 
-import os
+from typing import Any
+
 import logging
+import os
 from functools import lru_cache
 
 import gnupg
@@ -30,118 +32,121 @@ from gajim.common.util.classes import Singleton
 
 from pgp.exceptions import SignError
 
-
-logger = logging.getLogger('gajim.p.pgplegacy')
+logger = logging.getLogger("gajim.p.pgplegacy")
 if logger.getEffectiveLevel() == logging.DEBUG:
-    logger = logging.getLogger('gnupg')
+    logger = logging.getLogger("gnupg")
     logger.addHandler(logging.StreamHandler())
     logger.setLevel(logging.DEBUG)
 
 
-class PGP(gnupg.GPG, metaclass=Singleton):
-    def __init__(self, binary, encoding=None):
-        super().__init__(gpgbinary=binary,
-                         use_agent=True)
+class PGP(metaclass=Singleton):
+    def __init__(self) -> None:
+        self._pgp = gnupg.GPG(use_agent=True)
+        self._pgp.decode_errors = "replace"
 
-        if encoding is not None:
-            self.encoding = encoding
-        self.decode_errors = 'replace'
-
-    def encrypt(self, payload, recipients, always_trust=False):
+    def encrypt(
+        self, data: str, recipients: list[str], always_trust: bool = False
+    ) -> tuple[str, str]:
         if not always_trust:
             # check that we'll be able to encrypt
             result = self.get_key(recipients[0])
             for key in result:
-                if key['trust'] not in ('f', 'u'):
-                    return '', 'NOT_TRUSTED ' + key['keyid'][-8:]
+                if key["trust"] not in ("f", "u"):
+                    return "", "NOT_TRUSTED " + key["keyid"][-8:]
 
-        result = super().encrypt(
-            payload.encode('utf8'),
-            recipients,
-            always_trust=always_trust)
+        result = self._pgp.encrypt(
+            data.encode("utf8"), recipients, always_trust=always_trust
+        )
 
         if result.ok:
-            error = ''
+            error = ""
         else:
             error = result.status
 
         return self._strip_header_footer(str(result)), error
 
-    def decrypt(self, payload):
-        data = self._add_header_footer(payload, 'MESSAGE')
-        result = super().decrypt(data.encode('utf8'))
+    def encrypt_file(self, file: Any, recipients: list[str]) -> gnupg.Crypt:
+        return self._pgp.encrypt_file(file, recipients)
 
-        return result.data.decode('utf8')
+    def decrypt(self, payload: str) -> str:
+        data = self._add_header_footer(payload, "MESSAGE")
+        result = self._pgp.decrypt(data.encode("utf8"))
+        return str(result)
 
-    @lru_cache(maxsize=8)
-    def sign(self, payload, key_id):
+    @lru_cache(maxsize=8)  # noqa: B019
+    def sign(self, payload: str | None, key_id: str) -> str:
         if payload is None:
-            payload = ''
-        result = super().sign(payload.encode('utf8'),
-                              keyid=key_id,
-                              detach=True)
+            payload = ""
+        result = self._pgp.sign(payload.encode("utf8"), keyid=key_id, detach=True)
 
-        if result.fingerprint:
+        if result:
             return self._strip_header_footer(str(result))
         raise SignError(result.status)
 
-    def verify(self, payload, signed):
+    def verify(self, payload: str | None, signed: str) -> str | None:
         # Hash algorithm is not transferred in the signed
         # presence stanza so try all algorithms.
         # Text name for hash algorithms from RFC 4880 - section 9.4
 
         if payload is None:
-            payload = ''
+            payload = ""
 
-        hash_algorithms = ['SHA512', 'SHA384', 'SHA256',
-                           'SHA224', 'SHA1', 'RIPEMD160']
+        hash_algorithms = ["SHA512", "SHA384", "SHA256", "SHA224", "SHA1", "RIPEMD160"]
         for algo in hash_algorithms:
             data = os.linesep.join(
-                ['-----BEGIN PGP SIGNED MESSAGE-----',
-                 'Hash: ' + algo,
-                 '',
-                 payload,
-                 self._add_header_footer(signed, 'SIGNATURE')]
-                )
-            result = super().verify(data.encode('utf8'))
-            if result.valid:
+                [
+                    "-----BEGIN PGP SIGNED MESSAGE-----",
+                    "Hash: " + algo,
+                    "",
+                    payload,
+                    self._add_header_footer(signed, "SIGNATURE"),
+                ]
+            )
+            result = self._pgp.verify(data.encode("utf8"))
+            if result:
                 return result.fingerprint
 
-    def get_key(self, key_id):
-        return super().list_keys(keys=[key_id])
+    def get_key(self, key_id: str) -> gnupg.ListKeys:
+        return self._pgp.list_keys(keys=[key_id])
 
-    def get_keys(self, secret=False):
-        keys = {}
-        result = super().list_keys(secret=secret)
+    def get_keys(self, secret: bool = False) -> dict[str, str]:
+        keys: dict[str, str] = {}
+        result = self._pgp.list_keys(secret=secret)
 
         for key in result:
             # Take first not empty uid
-            keys[key['fingerprint']] = next(uid for uid in key['uids'] if uid)
+            keys[key["fingerprint"]] = next(uid for uid in key["uids"] if uid)
         return keys
 
+    def list_keys(
+        self, secret: bool = False, keys: list[str] | None = None, sigs: bool = False
+    ) -> list[str]:
+        res = self._pgp.list_keys(secret, keys, sigs)
+        return res.fingerprints
+
     @staticmethod
-    def _strip_header_footer(data):
+    def _strip_header_footer(data: str) -> str:
         """
         Remove header and footer from data
         """
         if not data:
-            return ''
+            return ""
         lines = data.splitlines()
-        while lines[0] != '':
+        while lines[0] != "":
             lines.remove(lines[0])
-        while lines[0] == '':
+        while lines[0] == "":
             lines.remove(lines[0])
         i = 0
         for line in lines:
             if line:
-                if line[0] == '-':
+                if line[0] == "-":
                     break
-            i = i+1
-        line = '\n'.join(lines[0:i])
+            i = i + 1
+        line = "\n".join(lines[0:i])
         return line
 
     @staticmethod
-    def _add_header_footer(data, type_):
+    def _add_header_footer(data: str, type_: str) -> str:
         """
         Add header and footer from data
         """
